import setuptools

setuptools.setup(
    name="daisynt",
    version="0.0.1",
    author="Giacomo Graffi",
    author_email="giacomo.graffi@gmail.com",
    description="Test Suite to enable Synthetic Data adoption",
    python_requires='>=3.6'
)